@@ -177,9 +177,10 @@ def call():
                 _devicePrint(device)
 
         if args.info:
-            _LOGGER.info('__main.py__.call().async_get_system()...')
+            _LOGGER.debug('__main.py__.call().async_get_system()...')
             #_LOGGER.info(json.dumps(lupusec.async_get_system(), indent=4, sort_keys=True))      
-            asyncio.run(lupusec.async_get_system()) 
+            asyncio.run(lupusec.async_get_system())
+            _LOGGER.info('__main.py__.call().async_get_system()...finished.')
                 
     except Exception as exc:
         _LOGGER.error(exc)
