@@ -4,7 +4,7 @@
 import lupulib.constants as CONST
 
 # Import device classes from lupulib
-import lupulib.devices.device
+# import lupulib.devices.device
 import lupulib.devices.binary_sensor
 import lupulib.devices.switch
 import lupulib.devices.system
